==> fluorine-orchestra-2.1.1.tgz: package/es/Collection.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _Symbol from 'babel-runtime/core-js/symbol';
import invariant from 'invariant';
import { OrderedMap } from 'extendable-immutable';
import { Set, OrderedSet } from 'immutable';

var groupsSymbol = _Symbol('groups');

export var Collection = function (_OrderedMap) {
  _inherits(Collection, _OrderedMap);

  function Collection() {
    _classCallCheck(this, Collection);

    return _possibleConstructorReturn(this, _OrderedMap.apply(this, arguments));
  }

  Collection.of = function of(val) {
    return new Collection(val);
  };

  Collection.isCollection = function isCollection(val) {
    return val && val instanceof Collection;
  };

  Collection.prototype.__wrapImmutable = function __wrapImmutable() {
    var _OrderedMap$prototype;

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var res = (_OrderedMap$prototype = _OrderedMap.prototype.__wrapImmutable).call.apply(_OrderedMap$prototype, [this].concat(args));

    if (res.size) {
      res[groupsSymbol] = this[groupsSymbol] || {};
    } else {
      res[groupsSymbol] = {};
    }

    return res;
  };

  Collection.prototype.merge = function merge(x) {
    if (!this.size) {
      return x;
    }

    var res = _OrderedMap.prototype.merge.call(this, x);
    if (!x instanceof Collection) {
      return res;
    }

    var xGroups = x[groupsSymbol] || {};
    var groups = res[groupsSymbol] || {};

    for (groupId in xGroups) {
      if (xGroups.hasOwnProperty(groupId)) {
        var _xGroup = xGroups[groupId] || new OrderedSet();
        var _group = groups[groupId] || new OrderedSet();

        groups[groupId] = _group.union(_xGroup);
      }
    }

    return res;
  };

  Collection.prototype.addIdToGroup = function addIdToGroup(groupId, id) {
    invariant(typeof groupId === 'string', 'Collection: `groupId` is expected to be an id (string).');
    invariant(typeof id === 'string', 'Collection: `id` is expected to be an id (string).');
    invariant(this.size && this.has(id), 'Collection: `id` is expected to be part of this collection.');

    var groups = this[groupsSymbol];

    var _group = groups[groupId] || new OrderedSet();
    groups[groupId] = _group.add(id);

    return this;
  };

  Collection.prototype.addIdsToGroup = function addIdsToGroup(groupId, ids) {
    var _this2 = this;

    invariant(typeof groupId === 'string', 'Collection: `groupId` is expected to be an id (string).');
    invariant(Set.isSet(ids) && ids.every(function (x) {
      return typeof x === 'string';
    }), 'Collection: `ids` is expected to be a Set containing ids (string).');
    invariant(this.size && ids.every(function (x) {
      return _this2.has(x);
    }), 'Collection: `ids` is expected to contain ids that are part of this collection.');

    var groups = this[groupsSymbol];

    var _group = groups[groupId] || new OrderedSet();
    groups[groupId] = _group.union(ids);

    return this;
  };

  Collection.prototype.filterForGroup = function filterForGroup(groupId) {
    var _this3 = this;

    invariant(typeof groupId === 'string', 'Collection: `groupId` is expected to be an id (string).');

    var groups = this[groupsSymbol] || {};
    var _group = groups[groupId] || new OrderedSet();

    var empty = this.clear();
    if (!_group.size) {
      return empty;
    }

    return empty.withMutations(function (map) {
      _group.forEach(function (id) {
        var item = _this3.get(id);
        if (item) {
          map.set(id, item);
        }
      });
    });
  };

  Collection.prototype.toString = function toString() {
    return this.__toString('Collection {', '}');
  };

  return Collection;
}(OrderedMap);

export default function createCollection(obj) {
  return new Collection(obj);
}

==> fluorine-orchestra-3.0.0.tgz: package/es/Collection.js <==
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _Symbol from 'babel-runtime/core-js/symbol';
import invariant from 'invariant';
import { OrderedMap } from 'extendable-immutable';
import { Set, OrderedSet } from 'immutable';

var groupsSymbol = _Symbol('groups');

export var Collection = function (_OrderedMap) {
  _inherits(Collection, _OrderedMap);

  function Collection() {
    _classCallCheck(this, Collection);

    return _possibleConstructorReturn(this, _OrderedMap.apply(this, arguments));
  }

  Collection.of = function of(val) {
    return new Collection(val);
  };

  Collection.isCollection = function isCollection(val) {
    return val && val instanceof Collection;
  };

  Collection.prototype.__wrapImmutable = function __wrapImmutable() {
    var _OrderedMap$prototype;

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    var res = (_OrderedMap$prototype = _OrderedMap.prototype.__wrapImmutable).call.apply(_OrderedMap$prototype, [this].concat(args));

    if (res.size) {
      res[groupsSymbol] = this[groupsSymbol] || {};
    } else {
      res[groupsSymbol] = {};
    }

    return res;
  };

  Collection.prototype.merge = function merge(x) {
    if (!this.size) {
      return x;
    }

    var res = _OrderedMap.prototype.merge.call(this, x);
    if (!x instanceof Collection) {
      return res;
    }

    var xGroups = x[groupsSymbol] || {};
    var groups = res[groupsSymbol] || {};

    for (var groupId in xGroups) {
      if (xGroups.hasOwnProperty(groupId)) {
        var _xGroup = xGroups[groupId] || new OrderedSet();
        var _group = groups[groupId] || new OrderedSet();

        groups[groupId] = _group.union(_xGroup);
      }
    }

    return res;
  };

  Collection.prototype.addIdToGroup = function addIdToGroup(groupId, id) {
    invariant(typeof groupId === 'string', 'Collection: `groupId` is expected to be an id (string).');
    invariant(typeof id === 'string', 'Collection: `id` is expected to be an id (string).');
    invariant(this.size && this.has(id), 'Collection: `id` is expected to be part of this collection.');

    var groups = this[groupsSymbol];

    var _group = groups[groupId] || new OrderedSet();
    groups[groupId] = _group.add(id);

    return this;
  };

  Collection.prototype.addIdsToGroup = function addIdsToGroup(groupId, ids) {
    var _this2 = this;

    invariant(typeof groupId === 'string', 'Collection: `groupId` is expected to be an id (string).');
    invariant(Set.isSet(ids) && ids.every(function (x) {
      return typeof x === 'string';
    }), 'Collection: `ids` is expected to be a Set containing ids (string).');
    invariant(this.size && ids.every(function (x) {
      return _this2.has(x);
    }), 'Collection: `ids` is expected to contain ids that are part of this collection.');

    var groups = this[groupsSymbol];

    var _group = groups[groupId] || new OrderedSet();
    groups[groupId] = _group.union(ids);

    return this;
  };

  Collection.prototype.filterForGroup = function filterForGroup(groupId) {
    var _this3 = this;

    invariant(typeof groupId === 'string', 'Collection: `groupId` is expected to be an id (string).');

    var groups = this[groupsSymbol] || {};
    var _group = groups[groupId] || new OrderedSet();

    var empty = this.clear();
    if (!_group.size) {
      return empty;
    }

    return empty.withMutations(function (map) {
      _group.forEach(function (id) {
        var item = _this3.get(id);
        if (item) {
          map.set(id, item);
        }
      });
    });
  };

  Collection.prototype.toString = function toString() {
    return this.__toString('Collection {', '}');
  };

  return Collection;
}(OrderedMap);

export default function createCollection(obj) {
  return new Collection(obj);
}
